package com.ruoyi.invest.mapper;

import java.util.List;
import com.ruoyi.invest.domain.TProjectReview;

/**
 * 评审记录Mapper接口
 * 
 * @author zjc
 * @date 2024-04-02
 */
public interface TProjectReviewMapper 
{
    /**
     * 查询评审记录
     * 
     * @param id 评审记录主键
     * @return 评审记录
     */
    public TProjectReview selectTProjectReviewById(String id);

    /**
     * 查询评审记录列表
     * 
     * @param tProjectReview 评审记录
     * @return 评审记录集合
     */
    public List<TProjectReview> selectTProjectReviewList(TProjectReview tProjectReview);

    /**
     * 新增评审记录
     * 
     * @param tProjectReview 评审记录
     * @return 结果
     */
    public int insertTProjectReview(TProjectReview tProjectReview);

    /**
     * 修改评审记录
     * 
     * @param tProjectReview 评审记录
     * @return 结果
     */
    public int updateTProjectReview(TProjectReview tProjectReview);

    /**
     * 删除评审记录
     * 
     * @param id 评审记录主键
     * @return 结果
     */
    public int deleteTProjectReviewById(String id);

    /**
     * 批量删除评审记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTProjectReviewByIds(String[] ids);
}
